==> libgal-0.2.0.tar.gz: libgal-0.2.0/star/gal_starpm_test.c <==
/*  
 *  - - - - - - - - - - - - - - - -  
 *   g a l _ s t a r p m _ t e s t  
 *  - - - - - - - - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     Test gal_starpm routine.  
 *  
 *  Status:  
 *  
 *     Internal test routine  
 *  
 *  Called:
 *  
 *     gal_starpm  
 *     gal_vdv  
 *     gal_viv  
 *  
 *  This Revision:
 *  
 *     2008 January 9 ( c version 2008 February 16 )  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 */  
  
#include "gal_starpm.h"  
#include "gal_starpm_test.h"  
#include "gal_test.h"  
  
void  
gal_starpm_test  
 (  
 )  
{  
    double ra1, dec1, pmr1, pmd1, px1, rv1,  
           ra2, dec2, pmr2, pmd2, px2, rv2 ;  
    int j ;  
  
    extern int gal_tfunc ;  
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
  
    ra1  =      0.01686756 ;  
    dec1 =    -1.093989828 ;  
    pmr1 = -1.78323516e-05 ;  
    pmd1 = 2.336024047e-06 ;  
    px1  =         0.74723 ;  
    rv1  =           -21.6 ;  
  
    gal_starpm ( ra1, dec1, pmr1, pmd1, px1, rv1, 2400000.5, 50083.0, 2400000.5, 53736.0,  
                    &ra2, &dec2, &pmr2, &pmd2, &px2, &rv2, &j ) ;  
  
    gal_vdv ( ra2,    0.01668919069414242368, 1e-12, "gal_starpm", "ra2" ) ;  
    gal_vdv ( dec2,    -1.093966454217127904, 1e-12, "gal_starpm", "dec2" ) ;  
    gal_vdv ( pmr2, -1.783662682155932489e-5, 1e-12, "gal_starpm", "pmr2" ) ;  
    gal_vdv ( pmd2,  2.338092915987605616e-6, 1e-12, "gal_starpm", "pmd2" ) ;  
    gal_vdv ( px2,     0.7473533835323492580, 1e-12, "gal_starpm", "px2" ) ;  
    gal_vdv ( rv2,     -21.59905170476860903, 1e-12, "gal_starpm", "rv2" ) ;  
    gal_viv ( j,                           0,        "gal_starpm", "j" ) ;  
  
    gal_tfunc++ ;  
  
/*  
 * Finished.  
 */  
  
}  
  
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */

==> libgal-0.5.0.tar.gz: libgal-0.5.0/star/gal_starpm_test.c <==
/*  
 *  - - - - - - - - - - - - - - - -  
 *   g a l _ s t a r p m _ t e s t  
 *  - - - - - - - - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     Test gal_starpm routine.  
 *  
 *  Status:  
 *  
 *     Internal test routine  
 *  
 *  Called:
 *  
 *     gal_starpm  
 *     gal_vdv  
 *     gal_viv  
 *  
 *  This Revision:
 *  
 *     2008 January 9 ( c version 2008 June 8 )  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 */  
  
#include "gal_starpm.h"  
#include "gal_starpm_test.h"  
#include "gal_test.h"  
  
void  
gal_starpm_test  
 (  
 )  
{  
    double ra1, dec1, pmr1, pmd1, px1, rv1,  
           ra2, dec2, pmr2, pmd2, px2, rv2 ;  
    int j ;  
  
    extern int gal_tfunc ;  
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
  
    ra1  =      0.01686756 ;  
    dec1 =    -1.093989828 ;  
    pmr1 = -1.78323516e-05 ;  
    pmd1 = 2.336024047e-06 ;  
    px1  =         0.74723 ;  
    rv1  =           -21.6 ;  
  
    j = gal_starpm ( ra1, dec1, pmr1, pmd1, px1, rv1, 2400000.5, 50083.0, 2400000.5, 53736.0,  
                    &ra2, &dec2, &pmr2, &pmd2, &px2, &rv2 ) ;  
  
    gal_vdv ( ra2,    0.01668919069414242368, 1e-12, "gal_starpm", "ra2" ) ;  
    gal_vdv ( dec2,    -1.093966454217127904, 1e-12, "gal_starpm", "dec2" ) ;  
    gal_vdv ( pmr2, -1.783662682155932489e-5, 1e-12, "gal_starpm", "pmr2" ) ;  
    gal_vdv ( pmd2,  2.338092915987605616e-6, 1e-12, "gal_starpm", "pmd2" ) ;  
    gal_vdv ( px2,     0.7473533835323492580, 1e-12, "gal_starpm", "px2" ) ;  
    gal_vdv ( rv2,     -21.59905170476860903, 1e-12, "gal_starpm", "rv2" ) ;  
    gal_viv ( j,                           0,        "gal_starpm", "j" ) ;  
  
    gal_tfunc++ ;  
  
/*  
 * Finished.  
 */  
  
}  
  
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */
